@@ -1,3 +1,3 @@
-from .tensorboard import ConfuseCallback, ModelSaverCallback
+from .tensorboard import ConfuseCallback, ModelSaverCallback, SparsityCallback
 from .tensorboard import run_tensorboard, wait_ctrl_c
 from .tensorboard import get_tf_callbacks
