@@ -226,7 +226,7 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
     """
     def __init__(self, best_metric=float('inf'), save_root="./", save_metric='val_loss',
                 metric_type="loss",file_name="my_model", enable=True, epoch=0, include_optimizer=False, save_func=None,
-                 keep_only_recent=False, save_every=True, batch_save=False, batch_save_step=100):
+                 keep_only_recent=True, save_every=False, batch_save=False, batch_save_step=100):
         """
 
         Args:
